pub struct MetadataGetPersistedMetadataResponse {
pub persisted_metadata: Vec<u8>,
}Fields
persisted_metadata: Vec<u8>Trait Implementations
Sourceimpl Clone for MetadataGetPersistedMetadataResponse
impl Clone for MetadataGetPersistedMetadataResponse
Sourcefn clone(&self) -> MetadataGetPersistedMetadataResponse
fn clone(&self) -> MetadataGetPersistedMetadataResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<MetadataGetPersistedMetadataResponse<'static>, ___E> for &'a MetadataGetPersistedMetadataResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<MetadataGetPersistedMetadataResponse<'static>, ___E> for &'a MetadataGetPersistedMetadataResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetadataGetPersistedMetadataResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetadataGetPersistedMetadataResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<MetadataGetPersistedMetadataResponse<'static>, ___E> for MetadataGetPersistedMetadataResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<MetadataGetPersistedMetadataResponse<'static>, ___E> for MetadataGetPersistedMetadataResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<MetadataGetPersistedMetadataResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<MetadataGetPersistedMetadataResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, MetadataGetPersistedMetadataResponse<'static>>, ___E> for &'a MetadataGetPersistedMetadataResponsewhere
___E: Encoder + ?Sized,
&'a MetadataGetPersistedMetadataResponse: Encode<MetadataGetPersistedMetadataResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, MetadataGetPersistedMetadataResponse<'static>>, ___E> for &'a MetadataGetPersistedMetadataResponsewhere
___E: Encoder + ?Sized,
&'a MetadataGetPersistedMetadataResponse: Encode<MetadataGetPersistedMetadataResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a MetadataGetPersistedMetadataResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetadataGetPersistedMetadataResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a MetadataGetPersistedMetadataResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetadataGetPersistedMetadataResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, MetadataGetPersistedMetadataResponse<'static>>, ___E> for MetadataGetPersistedMetadataResponsewhere
___E: Encoder + ?Sized,
MetadataGetPersistedMetadataResponse: Encode<MetadataGetPersistedMetadataResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, MetadataGetPersistedMetadataResponse<'static>>, ___E> for MetadataGetPersistedMetadataResponsewhere
___E: Encoder + ?Sized,
MetadataGetPersistedMetadataResponse: Encode<MetadataGetPersistedMetadataResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<MetadataGetPersistedMetadataResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, MetadataGetPersistedMetadataResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<MetadataGetPersistedMetadataResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, MetadataGetPersistedMetadataResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<MetadataGetPersistedMetadataResponse<'de>> for MetadataGetPersistedMetadataResponse
impl<'de> FromWire<MetadataGetPersistedMetadataResponse<'de>> for MetadataGetPersistedMetadataResponse
Sourcefn from_wire(
wire: MetadataGetPersistedMetadataResponse<'de>,
) -> MetadataGetPersistedMetadataResponse
fn from_wire( wire: MetadataGetPersistedMetadataResponse<'de>, ) -> MetadataGetPersistedMetadataResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<MetadataGetPersistedMetadataResponse<'de>> for MetadataGetPersistedMetadataResponse
impl<'de> FromWireRef<MetadataGetPersistedMetadataResponse<'de>> for MetadataGetPersistedMetadataResponse
Sourcefn from_wire_ref(
wire: &MetadataGetPersistedMetadataResponse<'de>,
) -> MetadataGetPersistedMetadataResponse
fn from_wire_ref( wire: &MetadataGetPersistedMetadataResponse<'de>, ) -> MetadataGetPersistedMetadataResponse
Converts the given reference to this type.
Sourceimpl Ord for MetadataGetPersistedMetadataResponse
impl Ord for MetadataGetPersistedMetadataResponse
Sourcefn cmp(&self, other: &MetadataGetPersistedMetadataResponse) -> Ordering
fn cmp(&self, other: &MetadataGetPersistedMetadataResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MetadataGetPersistedMetadataResponse
impl PartialEq for MetadataGetPersistedMetadataResponse
Sourcefn eq(&self, other: &MetadataGetPersistedMetadataResponse) -> bool
fn eq(&self, other: &MetadataGetPersistedMetadataResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MetadataGetPersistedMetadataResponse
impl PartialOrd for MetadataGetPersistedMetadataResponse
impl Eq for MetadataGetPersistedMetadataResponse
impl StructuralPartialEq for MetadataGetPersistedMetadataResponse